import React, { useEffect } from 'react';
import { Container, Typography, Button } from '@material-ui/core';
import { AddBox, ArrowDownward } from "@material-ui/icons";
import MaterialTable from "material-table";
import Check from '@material-ui/icons/Check';
import ChevronLeft from '@material-ui/icons/ChevronLeft';
import ChevronRight from '@material-ui/icons/ChevronRight';
import Clear from '@material-ui/icons/Clear';
import DeleteOutline from '@material-ui/icons/DeleteOutline';
import Edit from '@material-ui/icons/Edit';
import FilterList from '@material-ui/icons/FilterList';
import FirstPage from '@material-ui/icons/FirstPage';
import LastPage from '@material-ui/icons/LastPage';
import Remove from '@material-ui/icons/Remove';
import SaveAlt from '@material-ui/icons/SaveAlt';
import Search from '@material-ui/icons/Search';
import ViewColumn from '@material-ui/icons/ViewColumn';
import { forwardRef } from 'react';

const channelName = window.location.href.split("/")[4]
const adminToken = window.location.href.split("/")[5]
const dataURL = "/botdeets/"+ channelName + "/" + adminToken

function BotDeets() {

  const [botState, setBotState] = React.useState({loading: true, botData: { commands: [{"command":"card","action":"RandomPrompt"},{"command":"whotosingwith","action":"AgingSinger"}]} });

  const tableIcons = {
    Add: forwardRef((props, ref) => <AddBox {...props} ref={ref} />),
    Check: forwardRef((props, ref) => <Check {...props} ref={ref} />),
    Clear: forwardRef((props, ref) => <Clear {...props} ref={ref} />),
    Delete: forwardRef((props, ref) => <DeleteOutline {...props} ref={ref} />),
    DetailPanel: forwardRef((props, ref) => <ChevronRight {...props} ref={ref} />),
    Edit: forwardRef((props, ref) => <Edit {...props} ref={ref} />),
    Export: forwardRef((props, ref) => <SaveAlt {...props} ref={ref} />),
    Filter: forwardRef((props, ref) => <FilterList {...props} ref={ref} />),
    FirstPage: forwardRef((props, ref) => <FirstPage {...props} ref={ref} />),
    LastPage: forwardRef((props, ref) => <LastPage {...props} ref={ref} />),
    NextPage: forwardRef((props, ref) => <ChevronRight {...props} ref={ref} />),
    PreviousPage: forwardRef((props, ref) => <ChevronLeft {...props} ref={ref} />),
    ResetSearch: forwardRef((props, ref) => <Clear {...props} ref={ref} />),
    Search: forwardRef((props, ref) => <Search {...props} ref={ref} />),
    SortArrow: forwardRef((props, ref) => <ArrowDownward {...props} ref={ref} />),
    ThirdStateCheck: forwardRef((props, ref) => <Remove {...props} ref={ref} />),
    ViewColumn: forwardRef((props, ref) => <ViewColumn {...props} ref={ref} />)
  };
  useEffect(() => {
    // We should only fetch once!
    if (botState.loading) {
      let actualURL = dataURL
      if (window.location.href.split("/")[2] === "192.168.1.111:3000") {
        //Frontend dev mode only
        actualURL = "/sampleData/bot.json"
      }
      fetch(actualURL).then((res) => res.json().then((data)=>{
        setBotState({botData: data, loading: false })
      }));
    }
  }, [setBotState, botState.loading]);

  if (botState.loading) {
    return <p>Sorry, still loading...</p>
  }
  
  const dd = botState.botData
  const cmds = dd.commands
  if (dd.hasleft) {
    return (
      <Container>
        <Typography variant="h5" component="h2" gutterBottom>
          The chatbot is currently <b>not</b> in your channel.  To change the settings, invite it to your channel using the button below :
        </Typography>
        <Typography variant="p">
          You really don't wanna do that, because it's not ready yet.
        </Typography>
        <Typography variant="p">
          <Button variant="contained" color="primary">Join my channel!</Button>
        </Typography>
      </Container>
    )
  } else {
    return (
      <Container>
        <Typography variant="h5" component="h2" gutterBottom>
          Coming soon! Bot control panel!
        </Typography>
        <div style={{ maxWidth: "100%", display: "none" }}>
        <MaterialTable
            editable={{
              isEditable: rowData => true,
              isDeletable: rowData => true,
              onRowAddCancelled: rowData => console.log('Row adding cancelled'),
              onRowUpdateCancelled: rowData => console.log('Row editing cancelled'),
              onRowUpdate: (newData, oldData) =>
                  new Promise((resolve, reject) => {
                      setTimeout(() => {
                        const index = cmds.indexOf(oldData);
                        let newCommands = cmds;
                        let newState = botState;
                        newCommands[index] = newData;
                        newState.botData.commands = newCommands;
                        setBotState(newState);
                        resolve();
                      }, 1000);
                  }),
              onRowDelete: oldData =>
                  new Promise((resolve, reject) => {
                      setTimeout(() => {
                        const index = cmds.indexOf(oldData);
                        let newCommands = cmds;
                        let newState = botState;
                        newCommands.splice(index, 1);
                        newState.botData.commands = newCommands;
                        setBotState(newState);
                        resolve();
                      }, 1000);
                  }),
              onRowAdd: newData =>
                  new Promise((resolve, reject) => {
                      setTimeout(() => {
                        let newCommands = cmds;
                        let newState = botState;
                        newCommands[cmds.length] = newData;
                        newState.botData.commands = newCommands;
                        setBotState(newState);
                        resolve();
                      }, 1000);
                }),
          }}
          icons={tableIcons}
          columns={[
            { title: "Command", field: "command" },
            {
              title: "Action description",
              field: "action",
              lookup: { RandomPrompt: "Random prompt", AgingSinger: "Singer I haven't sung with in ages", AgingSong: "Song I haven't sung in ages"},
             /* editComponent: tableData =>
              <Select
                id="action"
                className=""
                optionId="key"
                optionName="value"
                value={tableData.rowData.action}
                dataAutoId={dropdowns('action')}
              >
              <MenuItem value="RandomPrompt">Random prompt</MenuItem>
              <MenuItem value="AgingSinger">Singer I haven't sung with in ages</MenuItem>
              <MenuItem value="AgingSong">Song I haven't sung in ages</MenuItem>
              </Select>*/
            },
          ]}
          data={cmds}
          title="Commands"
          options={{
            search: false
          }}
        />
      </div>
      </Container>
    );
  }
}

export default BotDeets;
